==> kafka-3.9.1-src.tgz: kafka-3.9.1-src/shell/src/main/java/org/apache/kafka/shell/node/RootShellNode.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kafka.shell.node;

import org.apache.kafka.image.MetadataImage;
import org.apache.kafka.image.node.MetadataImageNode;
import org.apache.kafka.image.node.MetadataNode;

import java.util.Arrays;
import java.util.Collection;

/**
 * The root node of the Kafka metadata shell.
 */
public class RootShellNode implements MetadataNode {
    private final MetadataImage image;

    public RootShellNode(MetadataImage image) {
        this.image = image;
    }

    @Override
    public Collection<String> childNames() {
        return Arrays.asList(LocalShellNode.NAME, MetadataImageNode.NAME);
    }

    @Override
    public MetadataNode child(String name) {
        if (name.equals(LocalShellNode.NAME)) {
            return new LocalShellNode();
        } else if (name.equals(MetadataImageNode.NAME)) {
            return new MetadataImageNode(image);
        } else {
            return null;
        }
    }
}

==> kafka-4.1.1-src.tgz: kafka-4.1.1-src/shell/src/main/java/org/apache/kafka/shell/node/RootShellNode.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kafka.shell.node;

import org.apache.kafka.image.MetadataImage;
import org.apache.kafka.image.node.MetadataImageNode;
import org.apache.kafka.image.node.MetadataNode;

import java.util.Collection;
import java.util.List;

/**
 * The root node of the Kafka metadata shell.
 */
public class RootShellNode implements MetadataNode {
    private final MetadataImage image;

    public RootShellNode(MetadataImage image) {
        this.image = image;
    }

    @Override
    public Collection<String> childNames() {
        return List.of(LocalShellNode.NAME, MetadataImageNode.NAME);
    }

    @Override
    public MetadataNode child(String name) {
        if (name.equals(LocalShellNode.NAME)) {
            return new LocalShellNode();
        } else if (name.equals(MetadataImageNode.NAME)) {
            return new MetadataImageNode(image);
        } else {
            return null;
        }
    }
}
